---
title: <span class="badge builder"></span> ElasticsearchMovingAverageHoltWintersModelSettingsSettings
---
# <span class="badge builder"></span> ElasticsearchMovingAverageHoltWintersModelSettingsSettings

## Constructor

```python
ElasticsearchMovingAverageHoltWintersModelSettingsSettings()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> elasticsearch.ElasticsearchMovingAverageHoltWintersModelSettingsSettings
```

### <span class="badge object-method"></span> alpha

```python
def alpha(alpha: str) -> typing.Self
```

### <span class="badge object-method"></span> beta

```python
def beta(beta: str) -> typing.Self
```

### <span class="badge object-method"></span> gamma

```python
def gamma(gamma: str) -> typing.Self
```

### <span class="badge object-method"></span> pad

```python
def pad(pad: bool) -> typing.Self
```

### <span class="badge object-method"></span> period

```python
def period(period: str) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [ElasticsearchMovingAverageHoltWintersModelSettingsSettings](./object-ElasticsearchMovingAverageHoltWintersModelSettingsSettings.md)
